#
# sys_init.pl
#
# This script does some basic initialization and housekeeping for the application installer/uninstaller.
#
# *** Nothing in this script will normally need to be modified ***
#
# NOTE: Scripts must be included in the following order:
#
#	require "CommonDB.pl";
#	require "CommonMisc.pl";
#	require "$ScriptDir/init_sys.pl";
#	require "$ScriptDir/init_app.pl";
#

use Getopt::Std;
use File::Copy;
use File::Path;

select(STDERR); $| = 1; #No buffering
select(STDOUT); $| = 1; #No buffering

our $TRUE=1;  
our $FALSE=0;  

our $opt_c;
our $opt_b;
our $opt_l;
our $opt_e;
our $opt_o;
our $opt_p;

getopts('c:b:l:o:e:p:');

our %dds_conf;

our %signiant_ini;

if(! $opt_b){
	die("You must indicate the path to the application's base directory via the -b argument.");
}

our $baseDir = $opt_b;

if($baseDir =~ /^\"(.*)\"$/)
{
	$baseDir = $1;
}

if($baseDir =~ /^\'(.*)\'$/)
{
	$baseDir = $1;
}

our $configFile = CommonMisc->cleanQuotedPath($opt_c, "You must indicate the path to the main configuration file (dds.conf or dds.cfg) via the -c argument.");

our %dds_conf = CommonMisc->readDDSConfig($configFile);

our $iniPath = $dds_conf{"Applications configuration file"};

if($iniPath eq "")
{
	die("Cannot find the application configuration file entry (signiant.ini) in the main configuration file.");
}
else
{
	%signiant_ini = CommonMisc->readConfig($iniPath);
}

our $LOG_PATH = CommonMisc->cleanQuotedPath($opt_l, "You must supply a path to the log file via the -l argument.");
our $OUT_PATH = CommonMisc->cleanQuotedPath($opt_o, "You must supply a path to the output file via the -o argument.");
our $ERR_PATH = CommonMisc->cleanQuotedPath($opt_e, "You must supply a path to the error file via the -e argument.");

our $OEM = $opt_p;

open(STDERR, ">$ERR_PATH") || die "\nCan't redirect STDERR: $!\n";
open(STDOUT, ">$OUT_PATH") || die "\nCan't redirect STDOUT: $!\n";

our $os = CommonMisc->getOsType();

our $dirSep = "/";

if($os eq "win")
{
	$dirSep = "\\";
}

our $mainDdsDir = CommonMisc->getMainDir($dds_conf{"Install directory"});
our $ProductLogDir = $dds_conf{"Log directory"};		
our $ddsGroup = $dds_conf{"Group name"};

our $commonDB = eval{new CommonDB();} or die ($@);

$commonDB->setup($mainDdsDir, %signiant_ini);

if ($ddsGroup eq "")
{
	$ddsGroup = "root"
}

return 1;
